==> Mapster-1.5.6.1.zip: Mapster/Locale/koKR.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "koKR")
if not L then return end

L["Accuracy"] = "정확도"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "위치를 구별하기 쉽도록 플레이어의 화살표 크기를 조절합니다."
L["Alpha"] = "투명도"
L["Battlegrounds"] = "전장"
L["BattleMap"] = "전장 지도"
L["Blobs & Panels"] = "퀘스트 위치 및 패널"
L["Burning Crusade Instances"] = "불타는 성전 던전"
L["Burning Crusade Raids"] = "불타는 성전 공격대"
L["Cataclysm Instances"] = "대격변 던전"
L["Cataclysm Raids"] = "대격변 공격대"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "세계 지도가 열려있는 동안 화면 전체를 채우는게 싫다면 세계 지도의 크기를 변경하세요."
L["Classic Instances"] = "오리지널 던전"
L["Classic Raids"] = "오리지널 공격대"
L["Coordinates"] = "좌표"
L["Cursor"] = "커서"
L["Debug"] = "디버그"
L["Disable Mouse"] = "마우스 사용 안함"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "세계 지도에서 마우스 상호 작용을 사용하지 않습니다.(예: 지역 변경 등)"
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "세계 지도가 축소 모드일 때 마우스 상호 작용을 사용하지 않습니다.(예: 지역 변경 등)"
L["EJ Icon Scale"] = "던전 도감 아이콘 크기"
L["Enable BattleMap"] = "전장 지도 사용"
L["Enable Coordinates"] = "좌표 사용"
L["Enable FogClear"] = "미탐색 지역 표시 사용"
L["Enable Group Icons"] = "파티원 아이콘 사용"
L["Enable Instance Maps"] = "던전 지도 사용"
L["FogClear"] = "미탐색 지역"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "자신의 SavedVariables 파일 안에 새로운 데이터를 수집하지만, 패치 등으로 인해 지역 정보의 오류가 발생할 수 있습니다. 세계 지도의 미탐색 지역 표시가 제대로 동작하지 않는다면 데이터를 초기화 하세요."
L["Group Icons"] = "파티원 아이콘"
L["Hide Border"] = "테두리 숨김"
L["Hide Completely"] = "완전히 숨김"
L["Hide Map Button"] = "지도 버튼 숨김"
L["Hide Quest Panels"] = "퀘스트 패널 숨기기"
L["Hide Textures"] = "텍스쳐 숨김"
L["Hide the borders of the big map."] = "세계 지도의 테두리를 숨깁니다."
L["Hide the borders of the minimized map."] = "세계 지도가 축소 모드일 때 세계 지도의 테두리를 숨깁니다."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "전장 지도 주변의 텍스처를 숨깁니다. 다만 전장 지도 부분의 외곽선은 남겨둡니다."
L["Instance Maps"] = "던전 지도"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster는 세계 지도에 여러 가지 추가 기능을 부여합니다. 세계 지도의 양식 변경, 확장 플러그인에 대한 설정, 전체 캐릭터에 대해 서로 다른 프로필 설정이 가능합니다."
L["(Mini) Disable Mouse"] = "(축소) 마우스 사용 안함"
L["(Mini) Hide Border"] = "(축소) 테두리 숨김"
L["Minimized Alpha"] = "최소 투명도"
L["Minimized Scale"] = "최소 크기"
L["Note: You need to reload your UI after reseting the data!"] = "주의: 데이터를 초기화한 후에는 UI를 재시작해야 합니다."
L["Only WorldMap Blobs"] = "세계 지도에만 위치 표시"
L["Overlay Color"] = "미탐색 지역 색상"
L["Pandaria Instances"] = "판다리아 던전"
L["Pandaria Raids"] = "판다리아 공격대"
L["Player"] = "플레이어"
L["PlayerArrow Scale"] = "플레이어 화살표 크기"
L["POI Scale"] = "주요 관심 지점 크기"
L["Reset FogClear Data"] = "미탐색 지역 데이터 초기화"
L["Scale"] = "크기"
L["Scale of the big map."] = "세계 지도의 크기를 조절합니다."
L["Scale of the Encounter Journal Icons on the Map."] = "던전 도감 아이콘의 크기를 조절합니다."
L["Scale of the minimized map."] = "세계 지도가 축소 모드일 때 세계 지도의 크기를 조절합니다."
L["Scale of the POI Icons on the Map."] = "세계 지도에서 주요 관심 지점의 크기를 변경합니다."
L["Size on the Battle Map"] = "아이콘 크기 (전장 지도)"
L["Size on the World Map"] = "아이콘 크기 (세계 지도)"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "전장 지도의 양식을 변경할 수 있으며, 불필요한 텍스쳐나 PvP 개체를 삭제할 수 있도록 합니다."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "세계 지도에 플레이어의 현재 위치를 표시합니다. 또한 마우스 커서가 위치한 곳의 좌표도 표시합니다."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "세계 지도에서 안개를 걷어내어 모든 지역을 확인할 수 있도록 합니다. 추가적으로 미탐색 지역에 대한 색상 조절을 통해 반투명으로 표시할 수도 있습니다."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "세계 지도에 파티원 또는 공격대원을 아이콘으로 표시하고, 그 크기를 조절합니다."
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "던전 지도를 사용하면 던전이나 전장에 참여하지 않더라도 원하는 던전과 전장의 지도를 볼 수 있습니다."
L["The transparency of the big map."] = "세계 지도의 투명도를 조절합니다."
L["The transparency of the minimized map."] = "세계 지도가 축소 모드일 때 세계 지도의 투명도를 조절합니다."
L["Turn on debugging for the FogClear Module."] = "미탐색 지역 표시에 대한 디버깅 기능을 사용합니다."
L["Wrath Instances"] = "리치왕의 분노 던전"
L["Wrath Raids"] = "리치왕의 분노 공격대"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "이동이 편리하도록 지도를 연 상태로 주변을 볼 수 있도록 세계 지도의 투명도를 조절합니다."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "좌표 표시의 소숫점 자릿수를 변경합니다. 보다 정확한 좌표를 위해 소숫점 두자리까지 설정할 수 있습니다."

==> Mapster-1.6.6.zip: Mapster/Locale/koKR.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "koKR")
if not L then return end

L["Accuracy"] = "정확도"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "위치를 구별하기 쉽도록 플레이어의 화살표 크기를 조절합니다."
L["Alpha"] = "투명도"
L["BattleMap"] = "전장 지도"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "세계 지도가 열려있는 동안 화면 전체를 채우는게 싫다면 세계 지도의 크기를 변경하세요."
L["Coordinates"] = "좌표"
L["Cursor"] = "커서"
L["Disable Mouse"] = "마우스 사용 안함"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "세계 지도에서 마우스 상호 작용을 사용하지 않습니다.(예: 지역 변경 등)"
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "세계 지도가 축소 모드일 때 마우스 상호 작용을 사용하지 않습니다.(예: 지역 변경 등)"
L["EJ Icon Scale"] = "던전 도감 아이콘 크기"
L["Enable BattleMap"] = "전장 지도 사용"
L["Enable Coordinates"] = "좌표 사용"
L["Enable FogClear"] = "미탐색 지역 표시 사용"
L["Enable Group Icons"] = "파티원 아이콘 사용"
L["Faded Alpha"] = "이동시 투명도" -- Needs review
L["FogClear"] = "미탐색 지역"
L["Font Size"] = "글꼴 크기"
L["Font Size on the minimized map."] = "축소된 맵의 글꼴 크기를 변경합니다."
L["Font Size on the normal map."] = "글꼴 크기를 변경합니다."
L["Group Icons"] = "파티원 아이콘"
L["Hide Border"] = "테두리 숨김"
L["Hide Map Button"] = "지도 버튼 숨김"
L["Hide Textures"] = "텍스쳐 숨김"
L["Hide the borders of the big map."] = "세계 지도의 테두리를 숨깁니다."
L["Hide the borders of the minimized map."] = "세계 지도가 축소 모드일 때 세계 지도의 테두리를 숨깁니다."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "전장 지도 주변의 텍스처를 숨깁니다. 다만 전장 지도 부분의 외곽선은 남겨둡니다."
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster는 세계 지도에 여러 가지 추가 기능을 부여합니다. 세계 지도의 양식 변경, 확장 플러그인에 대한 설정, 전체 캐릭터에 대해 서로 다른 프로필 설정이 가능합니다."
L["(Mini) Disable Mouse"] = "(축소) 마우스 사용 안함"
L["(Mini) Font Size"] = "(축소) 글꼴 크기"
L["(Mini) Hide Border"] = "(축소) 테두리 숨김"
L["Minimized Alpha"] = "최소 투명도"
L["Minimized Scale"] = "최소 크기"
L["Overlay Color"] = "미탐색 지역 색상"
L["Player"] = "플레이어"
L["PlayerArrow Scale"] = "플레이어 화살표 크기"
L["POI Scale"] = "주요 관심 지점 크기"
L["Scale"] = "크기"
L["Scale of the big map."] = "세계 지도의 크기를 조절합니다."
L["Scale of the Encounter Journal Icons on the Map."] = "던전 도감 아이콘의 크기를 조절합니다."
L["Scale of the minimized map."] = "세계 지도가 축소 모드일 때 세계 지도의 크기를 조절합니다."
L["Scale of the POI Icons on the Map."] = "세계 지도에서 주요 관심 지점의 크기를 변경합니다."
L["Size on the Battle Map"] = "아이콘 크기 (전장 지도)"
L["Size on the World Map"] = "아이콘 크기 (세계 지도)"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "전장 지도의 양식을 변경할 수 있으며, 불필요한 텍스쳐나 PvP 개체를 삭제할 수 있도록 합니다."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "세계 지도에 플레이어의 현재 위치를 표시합니다. 또한 마우스 커서가 위치한 곳의 좌표도 표시합니다."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "세계 지도에서 안개를 걷어내어 모든 지역을 확인할 수 있도록 합니다. 추가적으로 미탐색 지역에 대한 색상 조절을 통해 반투명으로 표시할 수도 있습니다."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "세계 지도에 파티원 또는 공격대원을 아이콘으로 표시하고, 그 크기를 조절합니다."
L["The map will fade out to the configured Fade Alpha level when you start moving."] = "현재 지도는 이동시 투명도가 바뀌도록 설정되어 있습니다." -- Needs review
L["The transparency of the big map."] = "세계 지도의 투명도를 조절합니다."
L["The transparency of the map while you are moving and the map is faded."] = "이동시 세계지도의 투명도를 변경합니다." -- Needs review
L["The transparency of the minimized map."] = "세계 지도가 축소 모드일 때 세계 지도의 투명도를 조절합니다."
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "이동이 편리하도록 지도를 연 상태로 주변을 볼 수 있도록 세계 지도의 투명도를 조절합니다."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "좌표 표시의 소숫점 자릿수를 변경합니다. 보다 정확한 좌표를 위해 소숫점 두자리까지 설정할 수 있습니다."
